@@ -136,8 +136,7 @@ def default_data_fn(data, target, model, dataset):
 
 def train_epoch(epoch, train_loader, model, optimizer, loss_fn, log_fn=default_log_fn, data_fn=default_data_fn,
                 scheduler=None, device="cpu", completed_steps=0, train_steps=None,
-                checkpoint_dir="", model_name=None, val_loader=None,
-                wandb_logging=False,
+                checkpoint_dir="", model_name=None, val_loader=None, wandb_logging=False,
                 grad_clip_norm=None, accumulation_steps=1,
                 mixed_precision=False, loss_backoff=InvalidLossBackoff(10, "consecutive"),
                 checkpoint_freq=None, val_freq=None, info_freq=None):
@@ -362,10 +361,12 @@ def train(epochs, train_steps, benchmark_name, model, train_loader, optimizer, l
         
         # Train loop
         if epochs is not None:
+            completed_steps = 0
             for epoch in range(1, epochs + 1):
                 # Train epoch
-                train_epoch(
-                    epoch=epoch, train_loader=train_loader, val_loader=val_loader,
+                completed_steps = train_epoch(
+                    epoch=epoch, completed_steps=completed_steps,
+                    train_loader=train_loader, val_loader=val_loader,
                     model=model, optimizer=optimizer, scheduler=scheduler,
                     loss_fn=loss_fn, log_fn=log_fn, data_fn=data_fn, device=device,
                     checkpoint_dir=checkpoint_dir, model_name=model_name,
@@ -391,7 +392,8 @@ def train(epochs, train_steps, benchmark_name, model, train_loader, optimizer, l
             epoch = 1
             while completed_steps < train_steps:
                 completed_steps = train_epoch(
-                    epoch=epoch, completed_steps=completed_steps, train_steps=train_steps, train_loader=train_loader, val_loader=val_loader,
+                    epoch=epoch, completed_steps=completed_steps, train_steps=train_steps,
+                    train_loader=train_loader, val_loader=val_loader,
                     model=model, optimizer=optimizer, scheduler=scheduler,
                     loss_fn=loss_fn, log_fn=log_fn, data_fn=data_fn, device=device,
                     checkpoint_dir=checkpoint_dir, model_name=model_name,
